@@ -827,7 +827,7 @@ def connect_to(display_desc, debug_cb=None, ssh_fail_cb=ssh_connect_failed):
     if dtype == "ssh":
         cmd = display_desc["full_ssh"]
         proxy_cmd = display_desc["remote_xpra"] + display_desc["proxy_command"] + display_desc["display_as_args"]
-        cmd += ["sh -c 'xpra initenv 2>&1 >> /dev/null;"+(" ".join(proxy_cmd))+"'"]
+        cmd += ["sh -c 'xpra initenv >> /dev/null 2>&1;"+(" ".join(proxy_cmd))+"'"]
         try:
             kwargs = {}
             kwargs["stderr"] = sys.stderr
@@ -953,6 +953,13 @@ def run_client(parser, opts, extra_args, mode):
         app = DetachXpraClient(connect(), opts)
     else:
         app = make_client(parser.error, opts)
+        layouts = app.get_supported_window_layouts() or ["default"]
+        layouts_str = ", ".join(layouts)
+        if opts.window_layout and opts.window_layout.lower()=="help":
+            print("%s supports the following layouts: %s" % (app.client_toolkit(), layouts_str))
+            return 0
+        if opts.window_layout and opts.window_layout not in layouts:
+            parser.error("window layout '%s' is not supported by the %s toolkit, valid options are: %s" % (opts.window_layout, app.client_toolkit(), layouts_str))
         app.init(opts)
         if opts.encoding:
             #fix old encoding names if needed:
@@ -965,13 +972,6 @@ def run_client(parser, opts, extra_args, mode):
                 if err:
                     return 1
                 return 0
-        layouts = app.get_supported_window_layouts() or ["default"]
-        layouts_str = ", ".join(layouts)
-        if opts.window_layout and opts.window_layout.lower()=="help":
-            print("%s supports the following layouts: %s" % (app.client_toolkit(), layouts_str))
-            return 0
-        if opts.window_layout and opts.window_layout not in layouts:
-            parser.error("window layout '%s' is not supported by the %s toolkit, valid options are: %s" % (opts.window_layout, app.client_toolkit(), layouts_str))
         def handshake_complete(*args):
             from xpra.log import Logger
             log = Logger()
